OC.L10N.register(
    "files",
    {
    "File could not be found" : "Fichier introuvable",
    "Move or copy" : "Déplacer ou copier",
    "Download" : "Télécharger",
    "Delete" : "Supprimer",
    "Tags" : "Étiquettes",
    "Show list view" : "Activer l'affichage liste",
    "Show grid view" : "Afficher l'affichage mosaïque",
    "Home" : "Accueil",
    "Close" : "Fermer",
    "Could not create folder \"{dir}\"" : "Impossible de créer le dossier \"{dir}\"",
    "This will stop your current uploads." : "Cela va arrêter vos envois en cours.",
    "Upload cancelled." : "Envoi annulé.",
    "Processing files …" : "Fichiers en cours de traitement …",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossible de téléverser {filename} car il s'agit d'un dossier ou d'un fichier vide",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Espace libre insuffisant : vous tentez d'envoyer {size1} mais seulement {size2} sont disponibles",
    "Target folder \"{dir}\" does not exist any more" : "Le dossier cible \"{dir}\" n'existe plus",
    "Not enough free space" : "Espace disponible insuffisant",
    "An unknown error has occurred" : "Une erreur inconnue est survenue",
    "File could not be uploaded" : "Le fichier n'a pas pu être téléversé",
    "Uploading …" : "Envoi en cours...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Téléversement en cours… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} sur {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "L'envoi de cet élément n'est pas supporté",
    "Target folder does not exist any more" : "Le dossier cible n'existe plus",
    "Operation is blocked by access control" : "L'opération est bloquée par le contrôle d'accès",
    "Error when assembling chunks, status code {status}" : "Erreur lors de l'assemblage des blocs, code d'état {status}",
    "Actions" : "Actions",
    "Rename" : "Renommer",
    "Move" : "Déplacer",
    "Copy" : "Copier",
    "Choose target folder" : "Sélectionner le dossier cible",
    "Set reminder" : "Définir un rappel",
    "Edit locally" : "Éditer localement",
    "Open" : "Ouvrir",
    "Delete file" : "Supprimer le fichier",
    "Delete folder" : "Supprimer le dossier",
    "Disconnect storage" : "Déconnecter ce support de stockage",
    "Leave this share" : "Quitter ce partage",
    "Could not load info for file \"{file}\"" : "Impossible de charger les informations du fichier \"{file}\"",
    "Files" : "Fichiers",
    "Details" : "Détails",
    "Please select tag(s) to add to the selection" : "Veuillez sélectionner la ou les étiquette(s) à ajouter à la sélection",
    "Apply tag(s) to selection" : "Appliquer la ou les étiquette(s) à la sélection",
    "Select directory \"{dirName}\"" : "Sélectionner le dossier \"{dirName}\"",
    "Select file \"{fileName}\"" : "Sélectionner le fichier \"{fileName}\"",
    "Pending" : "En attente",
    "Unable to determine date" : "Impossible de déterminer la date",
    "This operation is forbidden" : "Cette opération est interdite",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ce répertoire est indisponible, merci de consulter les journaux ou de contacter votre administrateur",
    "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
    "Could not move \"{file}\", target exists" : "Impossible de déplacer « {file} », la cible existe",
    "Could not move \"{file}\"" : "Impossible de déplacer \"{file}\"",
    "copy" : "copie",
    "Could not copy \"{file}\", target exists" : "Impossible de copier \"{file}\", la cible existe",
    "Could not copy \"{file}\"" : "Impossible de copier \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} copié dans {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} et {nbfiles} autres fichiers copiés dans {destination}",
    "Failed to redirect to client" : "Échec de la redirection vers le client",
    "{newName} already exists" : "{newName} existe déjà",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossible de renommer \"{fileName}\" car il n'existe plus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{targetName}\" est déjà utilisé dans le dossier \"{dir}\". Merci de choisir un nom différent.",
    "Could not rename \"{fileName}\"" : "Impossible de renommer « {fileName} »",
    "Could not create file \"{file}\"" : "Impossible de créer le fichier \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossible de créer le fichier « {file} » car il existe déjà",
    "Could not create folder \"{dir}\" because it already exists" : "Impossible de créer le dossier \"{dir}\" car il existe déjà",
    "Could not fetch file details \"{file}\"" : "Impossible de récupérer les détails du fichier \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Erreur à la suppression du fichier \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Aucun résultat dans d'autres dossiers pour {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Entrez plus de deux caractères pour effectuer une recherche dans d'autres dossiers",
    "Name" : "Nom",
    "Size" : "Taille",
    "Modified" : "Modifié",
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers","%n dossiers"],
    "_%n file_::_%n files_" : ["%n fichier","%n fichiers","%n fichiers"],
    "{dirs} and {files}" : "{dirs} et {files}",
    "_including %n hidden_::_including %n hidden_" : ["dont %n masqué","dont %n masqués","dont %n masqués"],
    "You do not have permission to upload or create files here" : "Vous n'avez pas la permission de téléverser ou de créer des fichiers ici",
    "_Uploading %n file_::_Uploading %n files_" : ["Téléversement de %n fichier","Envoi de %n fichiers","Envoi de %n fichiers"],
    "New" : "Nouveau",
    "New file/folder menu" : "Menu nouveau fichier/dossier",
    "Select file range" : "Activer la sélection d'une plage de fichiers",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} utilisés sur {quota}",
    "{used} used" : "{used} utilisés",
    "\"{name}\" is an invalid file name." : "\"{name}\" n'est pas un nom de fichier valide.",
    "File name cannot be empty." : "Le nom de fichier ne peut pas être vide.",
    "\"/\" is not allowed inside a file name." : "\"/\" n'est pas autorisé dans un nom de fichier.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" n'est pas un type de fichier autorisé",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "L'espace de stockage de {owner} est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Le dossier du groupe \"{mountPoint}\" est plein, les fichiers ne peuvent plus être mis à jour ou synchronisés !",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "L'espace de stockage externe \"{mountPoint}\" est plein, les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Your storage is full, files cannot be updated or synced anymore!" : "Votre espace de stockage est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "L'espace de stockage de {owner} est presque plein ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Le dossier de groupe \"{mountPoint}\" est presque plein ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "L'espace de stockage externe \"{mountPoint}\" est presque plein ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Votre espace de stockage est presque plein ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["correspond à \"{filter}\"","correspondent à '{filter}'","correspondent à '{filter}'"],
    "View in folder" : "Afficher dans le dossier",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Le lien direct a été copié (fonctionne uniquement pour les utilisateurs qui ont accès à ce fichier/dossier)",
    "Path" : "Chemin",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets","%n octets"],
    "Favorited" : "Marqué comme favori",
    "Favorite" : "Favoris",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copier le Lien direct (fonctionne uniquement pour les utilisateurs autorisés à accéder à ce fichier ou à ce dossier)",
    "New folder" : "Nouveau dossier",
    "Create new folder" : "Créer un nouveau dossier",
    "Upload file" : "Téléverser un fichier",
    "Recent" : "Récents",
    "Not favorited" : "Non marqué comme favori",
    "Remove from favorites" : "Retirer des favoris",
    "Add to favorites" : "Ajouter aux favoris",
    "An error occurred while trying to update the tags" : "Une erreur est survenue lors de la mise à jour des étiquettes",
    "Added to favorites" : "Ajouté aux favoris",
    "Removed from favorites" : "Retiré des favoris",
    "You added {file} to your favorites" : "Vous avez ajouté {file} à vos favoris",
    "You removed {file} from your favorites" : "Vous avez retiré {file} de vos favoris",
    "Favorites" : "Favoris",
    "File changes" : "Modifications de fichiers",
    "Created by {user}" : "Créé par {user}",
    "Changed by {user}" : "Modifié par {user}",
    "Deleted by {user}" : "Supprimé par {user}",
    "Restored by {user}" : "Restauré par {user}",
    "Renamed by {user}" : "Renommé par {user}",
    "Moved by {user}" : "Déplacé par {user}",
    "\"remote user\"" : "\"utilisateur distant\"",
    "You created {file}" : "Vous avez créé {file}",
    "You created an encrypted file in {file}" : "Vous avez créé un fichier chiffré dans {file}",
    "{user} created {file}" : "{user} a créé {file}",
    "{user} created an encrypted file in {file}" : "{user} a créé un fichier chiffré dans {file}",
    "{file} was created in a public folder" : "{file} a été créé dans un dossier public",
    "You changed {file}" : "Vous avez modifié {file}",
    "You changed an encrypted file in {file}" : "Vous avez modifié un fichier chiffré dans {file}",
    "{user} changed {file}" : "{user} a modifié {file}",
    "{user} changed an encrypted file in {file}" : "{user} a modifié un fichier chiffré dans {file}",
    "You deleted {file}" : "Vous avez supprimé {file}",
    "You deleted an encrypted file in {file}" : "Vous avez supprimé un fichier chiffré dans {file}",
    "{user} deleted {file}" : "{user} a supprimé {file}",
    "{user} deleted an encrypted file in {file}" : "{user} a supprimé un fichier chiffré dans {file}",
    "You restored {file}" : "Vous avez restauré {file}",
    "{user} restored {file}" : "{user} a restauré {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Vous avez renommé {oldfile} (hidden) en {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Vous avez renommé {oldfile} (hidden) en {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Vous avez renommé {oldfile} en {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "Vous avez renommé {oldfile} en {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} a renommé {oldfile} (hidden) en {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} a renommé {oldfile} (hidden) en {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} a renommé {oldfile} en {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} a renommé {oldfile} en {newfile}",
    "You moved {oldfile} to {newfile}" : "Vous avez déplacé {oldfile} dans {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} a déplacé {oldfile} dans {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un fichier a été ajouté ou retiré de vos <strong>favoris</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier a été <strong>modifié</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un fichier ou un dossier favori a été <strong>modifié </strong>",
    "Upload (max. %s)" : "Envoi (max. %s)",
    "Accept" : "Accepter",
    "Reject" : "Refuser",
    "Incoming ownership transfer from {user}" : "Transfert de propriété de la part de {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Voulez-vous accepter {path} ?\n\nN. B. : L'opération de transfert après acceptation peut prendre jusqu'à 1 heure.",
    "Ownership transfer failed" : "Le transfert de propriétaire a échoué",
    "Your ownership transfer of {path} to {user} failed." : "Votre transfert de propriété de {path} à {user} a échoué.",
    "The ownership transfer of {path} from {user} failed." : "Le transfert de propriété de {path} de {user} a échoué.",
    "Ownership transfer done" : "Transfert de propriétaire terminé",
    "Your ownership transfer of {path} to {user} has completed." : "Votre transfert de propriété de {path} à {user} est terminé.",
    "The ownership transfer of {path} from {user} has completed." : "Le transfert de propriété de {path} de {user} est terminé.",
    "in %s" : "dans %s",
    "File Management" : "Gestion de fichiers",
    "Current directory path" : "Chemin du répertoire courant",
    "Reload current directory" : "Rafraîchir le dossier courant",
    "Go to the \"{dir}\" directory" : "Aller au dossier \"{dir}\"",
    "Drag and drop files here to upload" : "Glissez-déposez les fichiers ici pour les téléverser",
    "Your have used your space quota and cannot upload files anymore" : "Vous avez utilisé votre quota d'espace et vous ne pouvez plus téléverser de fichiers",
    "You don’t have permission to upload or create files here" : "Vous n'avez pas la permission d'envoyer ou de créer des fichiers ici",
    "Upload successful" : "Téléversement réussi",
    "\"{displayName}\" action executed successfully" : "Action \"{displayName}\" exécutée avec succès",
    "\"{displayName}\" action failed" : "Échec de l'action \"{displayName}\"",
    "Toggle selection for file \"{displayName}\"" : "Basculer la sélection pour le fichier « {displayName} »",
    "Toggle selection for folder \"{displayName}\"" : "Basculer la sélection pour le dossier « {displayName} »",
    "Rename file" : "Renommer le fichier",
    "File name" : "Nom du fichier",
    "Folder name" : "Nom du dossier",
    "This node is unavailable" : "Ce nœud est indisponible ",
    "Download file {name}" : "Télécharger le fichier {name}",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" n'est pas un type de fichier autorisé.",
    "{newName} already exists." : "{newName} existe déjà.",
    "\"{char}\" is not allowed inside a file name." : "\"{char}\" n'est pas autorisé dans un nom de fichier.",
    "Name cannot be empty" : "Le nom ne peut pas être vide",
    "Another entry with the same name already exists" : "Une autre entrée avec le même nom existe déjà",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" renommé en \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "Impossible de renommer \"{oldName}\", il n'existe plus.",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nom \"{newName}\" est déjà utilisé dans le dossier \"{dir}\". Veuillez choisir un autre nom.",
    "Could not rename \"{oldName}\"" : "Impossible de renommer \"{oldName}\"",
    "Could not copy {file}. {message}" : "Impossible de copier {file}. {message}",
    "Could not move {file}. {message}" : "Impossible de déplacer {file}. {message}",
    "Total rows summary" : "Récapitulatif du nombre total de lignes",
    "Toggle selection for all files and folders" : "Basculer la sélection pour tous les fichiers et dossiers",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" a échoué sur certains éléments",
    "\"{displayName}\" batch action executed successfully" : "L'action « {displayName} » par lot a été exécutée avec succès",
    "List of files and folders." : "Liste des fichiers et dossiers.",
    "Column headers with buttons are sortable." : "L'entête des colonnes avec des boutons sont triables.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Cette liste n'est pas entièrement affichée pour des raisons de performances. Les fichiers seront affichés au fur et à mesure que vous naviguerez dans la liste.",
    "File not found" : "Fichier non trouvé",
    "Storage informations" : "Informations sur le stockage",
    "{usedQuotaByte} used" : "{usedQuotaByte} utilisés",
    "{relative}% used" : "{relative}% utilisés",
    "Could not refresh storage stats" : "Impossible de rafraîchir les statistiques de stockage",
    "Your storage is full, files can not be updated or synced anymore!" : "Votre espace de stockage est plein. Les fichiers ne peuvent plus être mis à jour ni synchronisés !",
    "Transfer ownership of a file or folder" : "Transférer la propriété d'un fichier ou d'un dossier",
    "Choose file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
    "Change" : "Modifier",
    "New owner" : "Nouveau propriétaire",
    "Choose a file or folder to transfer" : "Sélectionnez un fichier ou un dossier à transférer",
    "Transfer" : "Transférer",
    "Transfer {path} to {userid}" : "Transférer {path} à {userid}",
    "Invalid path selected" : "Chemin sélectionné non valide",
    "Unknown error" : "Erreur inconnue ",
    "Ownership transfer request sent" : "Requête de transfert de propriété envoyée",
    "Cannot transfer ownership of a file or folder you do not own" : "Impossible de transférer la propriété d'un fichier ou d'un dossier que vous ne possédez pas",
    "Select file or folder to link to" : "Sélectionnez le fichier ou le dossier à lier",
    "Choose file" : "Choisir un fichier",
    "Choose {file}" : "Choisir {file}",
    "Add" : "Ajouter",
    "Loading current folder" : "Chargement du dossier courant",
    "No files in here" : "Aucun fichier",
    "Upload some content or sync with your devices!" : "Déposez du contenu ou synchronisez vos appareils !",
    "Go to the previous folder" : "Aller au dossier précédent",
    "Go back" : "Revenir en arrière",
    "Share" : "Partager",
    "Shared by link" : "Partagés par lien",
    "Shared" : "Partagé",
    "Switch to list view" : "Basculer en vue liste",
    "Switch to grid view" : "Basculer en vue grille",
    "Error during upload: {message}" : "Erreur lors du téléversement : {message}",
    "Error during upload, status code {status}" : "Erreur lors du téléversement, code d'état {status}",
    "Unknown error during upload" : "Erreur inconnue lors du téléversement",
    "Open the files app settings" : "Ouvrir les paramètres de l'application Fichiers",
    "Files settings" : "Paramètres de Fichiers",
    "File cannot be accessed" : "Impossible d'accéder au fichier",
    "Sort favorites first" : "Trier les favoris d'abord",
    "Sort folders before files" : "Trier les dossiers avant les fichiers",
    "Show hidden files" : "Afficher les fichiers masqués",
    "Crop image previews" : "Afficher en miniatures carrées",
    "Enable the grid view" : "Activer la vue mosaïque",
    "Additional settings" : "Paramètres supplémentaires",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "URL WebDAV",
    "Copy to clipboard" : "Copier dans le presse-papiers",
    "Use this address to access your Files via WebDAV" : "Utilisez cette adresse pour accéder à vos fichiers via WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si vous avez activé le 2FA, vous devez créer et utiliser un nouveau mot de passe d'application en cliquant ici.",
    "Clipboard is not available" : "Le presse-papiers n'est pas disponible",
    "WebDAV URL copied to clipboard" : "URL WebDAV copiée dans le presse-papier",
    "Unable to change the favourite state of the file" : "Impossible de modifier l'état favori du fichier",
    "Error while loading the file data" : "Erreur lors du chargement du fichier de données",
    "Pick a template for {name}" : "Choisissez un modèle pour {name}",
    "Create" : "Créer",
    "Create a new file with the selected template" : "Créer un nouveau fichier avec le modèle sélectionné",
    "Creating file" : "Créer un fichier",
    "Blank" : "Vide",
    "Unable to create new file from template" : "Impossible de créer un nouveau fichier à partir du modèle",
    "Delete permanently" : "Supprimer définitivement",
    "Destination is not a folder" : "La destination n'est pas un dossier",
    "This file/folder is already in that directory" : "Ce fichier/dossier se trouve déjà dans ce dossier",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Vous ne pouvez pas déplacer un fichier/dossier sur lui-même ou dans un sous-dossier de celui-ci",
    "(copy)" : "(copier)",
    "(copy %n)" : "(copier %n)",
    "A file or folder with that name already exists in this folder" : "Un fichier ou un dossier portant ce nom existe déjà dans ce dossier",
    "The files is locked" : "Le fichier est verrouillé",
    "The file does not exist anymore" : "Le fichier n'existe plus",
    "Choose destination" : "Choisir la destination",
    "Copy to {target}" : "Copier vers {target}",
    "Move to {target}" : "Déplacer vers {target}",
    "Cancelled move or copy operation" : "Opération de déplacement ou de copie annulée",
    "Move or copy operation failed" : "L'opération de copie ou de déplacement a échoué",
    "Open folder {displayName}" : "Ouvrir le dossier {displayName}",
    "Open in Files" : "Ouvrir dans Fichiers",
    "Open details" : "Ouvrir les détails",
    "Create new templates folder" : "Créer un nouveau dossier de modèles",
    "Templates" : "Modèles",
    "Unable to initialize the templates directory" : "Impossible d'initialiser le dossier des modèles",
    "Created new folder \"{name}\"" : "Nouveau dossier \"{name}\" créé",
    "One of the dropped files could not be processed" : "L'un des fichiers déposés n'a pas pu être traité",
    "Uploading \"{filename}\" failed" : "Le téléversement de « {filename} » a échoué",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} dossier","{folderCount} dossiers","{folderCount} dossiers"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fichier","{fileCount} fichiers","{fileCount} fichiers"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fichier et {folderCount} dossier","1 fichier et {folderCount} dossiers","1 fichier et {folderCount} dossiers"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fichier et 1 dossier","{fileCount} fichiers et 1 dossier","{fileCount} fichiers et 1 dossier"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} fichiers et {folderCount} dossiers",
    "List of favorites files and folders." : "Liste des fichiers et dossiers favoris.",
    "No favorites yet" : "Aucun favori pour l'instant",
    "Files and folders you mark as favorite will show up here" : "Les fichiers et dossiers ajoutés à vos favoris apparaîtront ici",
    "All files" : "Tous les fichiers",
    "List of your files and folders." : "Liste de vos fichiers et dossiers.",
    "List of recently modified files and folders." : "Liste des fichiers et dossiers récemment modifiés.",
    "No recently modified files" : "Pas de fichiers récemment modifiés",
    "Files and folders you recently modified will show up here." : "Les fichiers et dossiers que vous avez récemment modifiés apparaîtront ici.",
    "No entries found in this folder" : "Aucune entrée trouvée dans ce dossier",
    "Select all" : "Tout sélectionner",
    "Upload too large" : "Données envoyées trop volumineuses",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Les fichiers que vous essayez d'envoyer dépassent la taille maximale d'envoi permise par ce serveur.",
    "Text file" : "Fichier texte",
    "New text file.txt" : "Nouveau fichier texte.txt",
    "You can only favorite a single file or folder at a time" : "Vous ne pouvez ajouter qu'un seul favori de dossier ou de fichier à la fois.",
    "Search users" : "Rechercher des utilisateurs",
    "You might not have have permissions to view it, ask the sender to share it" : "Vous n’avez peut-être pas les autorisations pour le voir, demandez à l’expéditeur de le partager",
    "Cancel" : "Annuler",
    "Set up templates folder" : "Configurer le dossier des modèles",
    "Toggle %1$s sublist" : "Basculer %1$s sous-liste",
    "Toggle grid view" : "Activer/Désactiver l'affichage mosaïque",
    "Deleted files" : "Fichiers supprimés",
    "Shares" : "Partages",
    "Shared with others" : "Partagés avec d'autres",
    "Shared with you" : "Partagés avec vous",
    "Deleted shares" : "Partages supprimés",
    "Pending shares" : "Partages en attente",
    "This file has the tag {tag}" : "Ce fichier a l'étiquette {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Ce fichier a les étiquettes {firstTags} et {lastTag}",
    "Select the row for {displayName}" : "Sélectionner la ligne pour {displayName}",
    "Open folder {name}" : "Ouvrir le dossier {name}",
    "Unselect all" : "Tout désélectionner",
    "ascending" : "ascendant",
    "descending" : "descendant",
    "Sort list by {column} ({direction})" : "Trier la liste par {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Cette liste n'est pas affichée en totalité pour des raisons de performances. Les fichiers seront affichés au fur et à mesure que vous parcourrez la liste.",
    "Search for an account" : "Chercher un compte",
    "Choose" : "Choisir",
    "No files or folders have been deleted yet" : "Aucun fichier ou dossier n'a encore été supprimé"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
